==> qt6-declarative_6.2.4+dfsg.orig.tar.xz: qtdeclarative-everywhere-src-6.2.4/tests/auto/quick/qquickfontloader_static/tst_qquickfontloader_static.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: http://www.qt-project.org/legal
**
** This file is part of the test suite of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtGui/QGuiApplication>
#include <QtQuick/QQuickView>
#include <QtQml/QQmlComponent>
#include <QtQuickTestUtils/private/qmlutils_p.h>
#include <qtest.h>

QByteArray qmltemplate("import QtQuick 2.0\n"
"\n"
"Rectangle {\n"
"    width: 400\n"
"    height: 400\n"
"    color: \"red\"\n"
"    FontLoader { id: fixedFont; source: \"%1\" }\n"
"    Text {\n"
"        text: \"hello world\"\n"
"        anchors.centerIn: parent\n"
"        font.family: fixedFont.name\n"
"    }\n"
"}\n");

int main(int argc, char **argv)
{
    for (int i = 0; i < 3; i++) {
        QGuiApplication app(argc, argv);
        QQmlDataTest dataTest(QT_QMLTEST_DATADIR);
        dataTest.initTestCase();
        QQuickView window;
        QQmlComponent component (window.engine());
        QUrl current = QUrl::fromLocalFile("");
        qmltemplate.replace("%1", dataTest.testFileUrl("font.ttf").toString().toLocal8Bit());
        component.setData(qmltemplate, current);
        window.setContent(current, &component, component.create());
        window.show();
        if (!QTest::qWaitForWindowActive(&window))
            return EXIT_FAILURE;
    }
    return 0;
}

==> qt6-declarative_6.9.2+dfsg.orig.tar.xz: qtdeclarative-everywhere-src-6.9.2/tests/auto/quick/qquickfontloader_static/tst_qquickfontloader_static.cpp <==
// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only

#include <QtGui/QGuiApplication>
#include <QtQuick/QQuickView>
#include <QtQml/QQmlComponent>
#include <QtQuickTestUtils/private/qmlutils_p.h>
#include <qtest.h>

QByteArray qmltemplate("import QtQuick 2.0\n"
"\n"
"Rectangle {\n"
"    width: 400\n"
"    height: 400\n"
"    color: \"red\"\n"
"    FontLoader { id: fixedFont; source: \"%1\" }\n"
"    Text {\n"
"        text: \"hello world\"\n"
"        anchors.centerIn: parent\n"
"        font.family: fixedFont.name\n"
"    }\n"
"}\n");

int actualTest(int argc, char **argv)
{
    for (int i = 0; i < 3; i++) {
        QGuiApplication app(argc, argv);
        QQmlDataTest dataTest(QT_QMLTEST_DATADIR);
        dataTest.initTestCase();
        QQuickView window;
        QQmlComponent component (window.engine());
        QUrl current = QUrl::fromLocalFile("");
        qmltemplate.replace("%1", dataTest.testFileUrl("font.ttf").toString().toLocal8Bit());
        component.setData(qmltemplate, current);
        window.setContent(current, &component, component.create());
        window.show();
        if (!QTest::qWaitForWindowActive(&window))
            return EXIT_FAILURE;
    }
    return 0;
}

// we need the QTestLib infrastructure to create a log file
struct FontLoaderStaticTester : public QObject
{
    Q_OBJECT

public:
    int result = -1;
private slots:
    void verify() {  QCOMPARE(result, 0); }
};

int main(int argc, char **argv)
{
    int result = actualTest(argc, argv);
    QCoreApplication app(argc, argv);
    FontLoaderStaticTester tester;
    tester.result = result;
    QTest::qExec(&tester, argc, argv);
}

#include "tst_qquickfontloader_static.moc"
